#
# spec file for package python-attrs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}

Name:           python-attrs
%global modname attrs
Version:        17.2.0
Release:        6.1
Summary:        Attributes without boilerplate
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/hynek/%{modname}/
Source:         https://pypi.io/packages/source/a/%{modname}/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
attrs is an MIT-licensed Python package with class decorators that ease the
chores of implementing the most common attribute-related object protocols.

You just specify the attributes to work with and attrs gives you:
  - a nice human-readable __repr__,
  - a complete set of comparison methods,
  - an initializer,
  - and much more

without writing dull boilerplate code again and again.

This gives you the power to use actual classes with actual types in your code
instead of confusing tuples or confusingly behaving namedtuples.

So put down that type-less data structures and welcome some class into your
life!

python-attrs is the successor to python-characterstic

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{_prefix}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.rst LICENSE README.rst
%{python_sitelib}/*
%{python_sitelib}/%{modname}-%{version}-py*.egg-info

%changelog
* Tue Jul  4 2017 tbechtold@suse.com
- update to 17.2.0:
  - Validators are hashable again.
  - ``attrs`` will set the ``__hash__()`` method to ``None`` by default now.
    The way hashes were handled before was in conflict with `Python's
    specification
    This *may* break some software although this breakage is most likely just
    surfacing of latent bugs.
    You can always make ``attrs`` create the ``__hash__()`` method using
    ``@attr.s(hash=True)``. See `#136`_ for the rationale of this change.
  - Correspondingly, ``attr.ib``'s ``hash`` argument is ``None`` by default too
    and mirrors the ``cmp`` argument as it should.
  - ``attr.assoc()`` is now deprecated in favor of ``attr.evolve()`` and will
    stop working in 2018.
  - Fix default hashing behavior.
    Now *hash* mirrors the value of *cmp* and classes are unhashable by default.
  - Added ``attr.evolve()`` that, given an instance of an ``attrs`` class and
    field changes as keyword arguments, will instantiate a copy of the given
    instance with the changes applied.
  - ``FrozenInstanceError`` is now raised when trying to delete an attribute
    from a frozen class.
  - Frozen-ness of classes is now inherited.
  - ``__attrs_post_init__()`` is now run if validation is disabled.
  - Added ``attr.validators.in_(options)`` that, given the allowed `options`,
    checks whether the attribute value is in it.
    This can be used to check constants, enums, mappings, etc.
  - Added ``attr.validators.and_()`` that composes multiple validators into one.
  - For convenience, the ``validator`` argument of ``@attr.s`` now can take a
    ``list`` of validators that are wrapped using ``and_()``.
  - Accordingly, ``attr.validators.optional()`` now can take a ``list`` of
    validators too.
  - Validators can now be defined conveniently inline by using the attribute as
    a decorator.
  - ``attr.Factory()`` now has a ``takes_self`` argument that makes the
    initializer to pass the partially initialized instance into the factory.
    In other words you can define attribute defaults based on other attributes.
  - Default factories can now also be defined inline using decorators.
    They are *always* passed the partially initialized instance.
  - Conversion can now be made optional using ``attr.converters.optional()``.
  - ``attr.make_class()`` now accepts the keyword argument ``bases`` which
    allows for subclassing.
  - Metaclasses are now preserved with ``slots=True``.
  - Attributes now can have user-defined metadata which greatly improves
    ``attrs``'s extensibility.
  - Allow for a ``__attrs_post_init__()`` method that -- if defined -- will get
    called at the end of the ``attrs``-generated ``__init__()`` method.
  - Added ``@attr.s(str=True)`` that will optionally create a ``__str__()``
    method that is identical to ``__repr__()``.
  - ``__name__`` is not overwritten with ``__qualname__`` for
    ``attr.s(slots=True)`` classes anymore.
  - Added ``attr.astuple()`` that -- similarly to ``attr.asdict()`` --
    returns the instance as a tuple.
  - Converts now work with frozen classes.
  - Instantiation of ``attrs`` classes with converters is now significantly
    faster.
  - Pickling now works with ``__slots__`` classes.
  - ``attr.assoc()`` now works with ``__slots__`` classes.
  - The tuple returned by ``attr.fields()`` now also allows to access the
    ``Attribute`` instances by name.
  - All instances where function arguments were called ``cl`` have been changed
    to the more Pythonic ``cls``.
  - Accessing ``Attribute`` instances on class objects is now deprecated and
    will stop working in 2017.
  - The serious business aliases ``attr.attributes`` and ``attr.attr`` have been
    deprecated in favor of ``attr.attrs`` and ``attr.attrib`` which are much
    more consistent and frankly obvious in hindsight.
  - ``attr.asdict()``\ 's ``dict_factory`` arguments is now propagated on
    recursion.
  - ``attr.asdict()``, ``attr.has()`` and ``attr.fields()`` are significantly
    faster.
  - Add ``attr.attrs`` and ``attr.attrib`` as a more consistent aliases for
    ``attr.s`` and ``attr.ib``.
  - Add ``frozen`` option to ``attr.s`` that will make instances best-effort
    immutable.
  - ``attr.asdict()`` now takes ``retain_collection_types`` as an argument.
* Sat Jul  1 2017 okurz@suse.com
- Convert to singlespec
* Tue Jul  5 2016 hpj@urpla.net
- update to 16.0.0
  Backward-incompatible changes:
  * Python 3.3 and 2.6 aren’t supported anymore. They may work by chance but
    any effort to keep them working has ceased.
    The last Python 2.6 release was on October 29, 2013 and isn’t supported by
    the CPython core team anymore. Major Python packages like Django and Twisted
    dropped Python 2.6 a while ago already.
    Python 3.3 never had a significant user base and wasn’t part of any
    distribution’s LTS release.
  Changes:
  * __slots__ have arrived! Classes now can automatically be slots-style (and
    save your precious memory) just by passing slots=True. #35
  * Allow the case of initializing attributes that are set to init=False. This
    allows for clean initializer parameter lists while being able to initialize
    attributes to default values. #32
  * attr.asdict can now produce arbitrary mappings instead of Python dicts when
    provided with a dict_factory argument. #40 Multiple performance improvements.
* Thu Jun  2 2016 tbechtold@suse.com
- fix Source url
* Thu Jun  2 2016 jacobwinski@gmail.com
- Initial version
